pub struct RandomForestClassifierSearchParameters {
pub criterion: Vec<SplitCriterion>,
pub max_depth: Vec<Option<u16>>,
pub min_samples_leaf: Vec<usize>,
pub min_samples_split: Vec<usize>,
pub n_trees: Vec<u16>,
pub m: Vec<Option<usize>>,
pub keep_samples: Vec<bool>,
pub seed: Vec<u64>,
}Expand description
RandomForestClassifier grid search parameters
Fields
criterion: Vec<SplitCriterion>Split criteria to use when building a tree. See Decision Tree Classifier
max_depth: Vec<Option<u16>>Tree max depth. See Decision Tree Classifier
min_samples_leaf: Vec<usize>The minimum number of samples required to be at a leaf node. See Decision Tree Classifier
min_samples_split: Vec<usize>The minimum number of samples required to split an internal node. See Decision Tree Classifier
n_trees: Vec<u16>The number of trees in the forest.
m: Vec<Option<usize>>Number of random sample of predictors to use as split candidates.
keep_samples: Vec<bool>Whether to keep samples used for tree generation. This is required for OOB prediction.
seed: Vec<u64>Seed used for bootstrap sampling and feature selection for each tree.