MultinomialNB

Struct MultinomialNB 

pub struct MultinomialNB<TX: Number + Unsigned, TY: Number + Ord + Unsigned, X: Array2<TX>, Y: Array1<TY>> { /* private fields */ }
MultinomialNB implements the naive Bayes algorithm for multinomially distributed data.

Implementations

Source

impl<TX: Number + Unsigned, TY: Number + Ord + Unsigned, X: Array2<TX>, Y: Array1<TY>> MultinomialNB<TX, TY, X, Y>

pub fn fit( x: &X, y: &Y, parameters: MultinomialNBParameters, ) -> Result<Self, Failed>

Fits MultinomialNB with given data

  • x - training data of size NxM where N is the number of samples and M is the number of features.
  • y - vector with target values (classes) of length N.
  • parameters - additional parameters like class priors, alpha for smoothing and binarizing threshold.
pub fn predict(&self, x: &X) -> Result<Y, Failed>

Estimates the class labels for the provided data.

  • x - data of shape NxM where N is number of data points to estimate and M is number of features.

Returns a vector of size N with class estimates.

pub fn classes(&self) -> &Vec<TY>

Class labels known to the classifier. Returns a vector of size n_classes.

pub fn class_count(&self) -> &Vec<usize>

Number of training samples observed in each class. Returns a vector of size n_classes.

pub fn feature_log_prob(&self) -> &Vec<Vec<f64>>

Empirical log probability of features given a class, P(x_i|y). Returns a 2d vector of shape (n_classes, n_features)

pub fn n_features(&self) -> usize

Number of features of each sample

pub fn feature_count(&self) -> &Vec<Vec<usize>>

Number of samples encountered for each (class, feature) Returns a 2d vector of shape (n_classes, n_features)