Module first_order

Module first_order 

first order optimization algorithms

Modules

gradient_descent
Gradient descent optimization algorithm
lbfgs
Limited-memory BFGS optimization algorithm

Structs

OptimizerResult
Result of optimization

Traits

FirstOrderOptimizer
First-order optimization is a class of algorithms that use the first derivative of a function to find optimal solutions.