pub struct DecisionTreeClassifierParameters {
pub criterion: SplitCriterion,
pub max_depth: Option<u16>,
pub min_samples_leaf: usize,
pub min_samples_split: usize,
pub seed: Option<u64>,
}Expand description
Parameters of Decision Tree
Fields
criterion: SplitCriterionSplit criteria to use when building a tree.
max_depth: Option<u16>The maximum depth of the tree.
min_samples_leaf: usizeThe minimum number of samples required to be at a leaf node.
min_samples_split: usizeThe minimum number of samples required to split an internal node.
seed: Option<u64>Controls the randomness of the estimator
Implementations
Sourceimpl DecisionTreeClassifierParameters
impl DecisionTreeClassifierParameters
Sourcepub fn with_criterion(self, criterion: SplitCriterion) -> Self
pub fn with_criterion(self, criterion: SplitCriterion) -> Self
Split criteria to use when building a tree.
Sourcepub fn with_max_depth(self, max_depth: u16) -> Self
pub fn with_max_depth(self, max_depth: u16) -> Self
The maximum depth of the tree.
Sourcepub fn with_min_samples_leaf(self, min_samples_leaf: usize) -> Self
pub fn with_min_samples_leaf(self, min_samples_leaf: usize) -> Self
The minimum number of samples required to be at a leaf node.
Sourcepub fn with_min_samples_split(self, min_samples_split: usize) -> Self
pub fn with_min_samples_split(self, min_samples_split: usize) -> Self
The minimum number of samples required to split an internal node.